package searchengine.model;

import java.net.URI;
import java.util.HashSet;
import java.util.Objects;
import java.util.Set;

public record Link(URI uri, int depth, Set<Link> children, Link parent) {
    public Link {
        children = new HashSet<>();
    }

    public Link(URI uri, Link parent) {
        this(uri, (parent == null) ? 0 : parent.depth() + 1, new HashSet<>(), parent);
    }

    public void addChild(URI childUri) {
        children.add(new Link(childUri, this));
    }

    // Переопределяем equals и hashCode, исключая поля children и parent
    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        Link link = (Link) o;
        return depth == link.depth && Objects.equals(uri, link.uri);
    }

    @Override
    public int hashCode() {
        return Objects.hash(uri, depth); // Исключаем children и parent
    }

    @Override
    public String toString() { // А он нужен?
        return "Link{" +
                "uri=" + uri +
                ", depth=" + depth +
                '}'; // Исключаем children и parent
    }
}